# -*- coding: utf-8 -*-
"""
@author: WYR。
"""
def add(x,y):
    return x+y

def division(x,y):
    return x/y

def mutiply(x,y):
    return x*y

def subtract(x,y):
    return x-y

def main():
    pass

if __name__ == '__main__':
    main()


# -*- coding: utf-8 -*-
"""
@author: WYR。
"""

from setuptools import setup

setup(
    name= 'package_wy',
    version= '1.0.0',
    packages = ['package_wy'],
    author='TuNan',
    author_email='wuuyanru@163.com',
    license='Apache',
)